@@ -1,10 +1,13 @@
 #' Registers the future \%dopar\% backend
 #'
-#' Register the \code{\link{doFuture}} parallel adaptor to be used by
+#' Register the [doFuture] parallel adapter to be used by
 #' the \pkg{foreach} package.
 #'
 #' @return Nothing
 #'
+#' @examples
+#' registerDoFuture()
+#' 
 #' @importFrom future nbrOfWorkers
 #' @importFrom foreach setDoPar
 #' @importFrom utils packageVersion
@@ -15,9 +18,8 @@ registerDoFuture <- function() {  #nolint
     switch(item,
       name = "doFuture",
       version = packageVersion("doFuture"),
-      workers = nbrOfWorkers()
+      workers = nbrOfWorkers(),
     )
   }
-
-  setDoPar(doFuture, data = NULL, info = info)
+  setDoPar(doFuture, info = info)
 }
