@@ -9,15 +9,14 @@ oplan <- future::plan()
 future::plan(future::sequential)
 doFuture::registerDoFuture()
 
-hpaste <- future:::hpaste
-mdebug <- future:::mdebug
+mdebug <- doFuture:::mdebug
+mprint <- doFuture:::mprint
+mstr <- doFuture:::mstr
 
 ## To please R CMD check when using require().
 future.batchtools <- "future.batchtools"  #nolint
 future.BatchJobs <- "future.BatchJobs"    #nolint
+caret <- "caret"                          #nolint
 plyr <- "plyr"                            #nolint
 BiocParallel <- "BiocParallel"            #nolint
-
-## Local functions for test scripts
-printf <- function(...) cat(sprintf(...))
-mstr <- function(...) message(paste(capture.output(str(...)), collapse = "\n"))
+NMF <- "NMF"                              #nolint
